clear all
set mem 650m
set matsize 4000
set more off
program drop _all
macro drop _all
capture log close

use AEJ_data_1rep.dta, replace

*********************************************************************************
* Table: impact of social capital on electoral punishment (interaction term)
*********************************************************************************

preserve

foreach x in rap_all_current_new {

gen inc`x'=`x'*income
gen edu`x'=`x'*edu_prov
gen news`x'=`x'*newspapers
gen blood`x'=`x'*donation
gen urb`x'=`x'*urbanization

gen ten_`x' = `x'*tenure
gen ten_don_`x' = `x'*tenure*donation
gen ten_don = tenure*donation

gen age_`x' = `x'*age
gen age_don_`x' = `x'*age*donation
gen age_don = age*donation

local controls years_educ gov_appoint loc_exp freshman govin north south tenure/*
*/ lawyer executive entrepreneur teacher physician politician age age_squared male duI-duX

*column (1) - no additional interactions
xi: reg dlogvotes `x' blood`x' `controls' i.district,r cluster(district)
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons replace nor tex(nopretty)

*column (2) - additional interactions
xi: reg dlogvotes `x' blood`x' inc`x' edu`x' news`x' urb`x' `controls' i.district,r cluster(district)
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons append nor tex(nopretty)

*column (3) - individual fe but no additional interactions
xi:xtreg dlogvotes `x' blood`x' `controls' i.district,fe
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons append nor tex(nopretty)

*column (4) - individual fe and additional interactions
xi:xtreg  dlogvotes blood`x' `x' inc`x' edu`x' news`x' urb`x' `controls' i.district,fe
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons append nor tex(nopretty)

}
restore

preserve

foreach x in rap_all_current_3 {
gen inc`x'=`x'*income
gen edu`x'=`x'*edu_prov
gen news`x'=`x'*newspapers
gen blood`x'=`x'*donation
gen urb`x'=`x'*urbanization

gen ten_`x' = `x'*tenure
gen ten_don_`x' = `x'*tenure*donation
gen ten_don = tenure*donation

gen age_`x' = `x'*age
gen age_don_`x' = `x'*age*donation
gen age_don = age*donation

local controls years_educ gov_appoint loc_exp freshman govin north south tenure/*
*/ lawyer executive entrepreneur teacher physician politician age age_squared male duI-duX

*column (1) - no additional interactions
xi: reg dlogvotes `x' blood`x' `controls' i.district,r cluster(district)
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons replace nor tex(nopretty)

*column (2) - additional interactions
xi: reg dlogvotes `x' blood`x' inc`x' edu`x' news`x' urb`x' `controls' i.district,r cluster(district)
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons append nor tex(nopretty)

*column (3) - individual fe but no additional interactions
xi:xtreg dlogvotes `x' blood`x' `controls' i.district,fe
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons append nor tex(nopretty)

*column (4) - individual fe and additional interactions
xi:xtreg  dlogvotes blood`x' `x' inc`x' edu`x' news`x' urb`x' `controls' i.district,fe
outreg2 blood`x' `x' years_educ gov_appoint loc_exp freshman tenure govin /*
*/ using Tab7_`x', bdec(3) brac nocons append nor tex(nopretty)

}
restore
